__version__ = '6.2.0'

from .tools import *  # NOQA: 401
from .account import *  # NOQA: 401
from .company import *  # NOQA: 401
from .currency import *  # NOQA: 401
from .invoice import *  # NOQA: 401
from .party import *  # NOQA: 401
from .product import *  # NOQA: 401
from .purchase import *  # NOQA: 401
from .sale import *  # NOQA: 401
from .sequence import *  # NOQA: 401
from .stock import *  # NOQA: 401
from .user import *  # NOQA: 401
from .wizards import *  # NOQA: 401
